@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import copy
 
 from trytond.model import ModelSQL, fields
@@ -71,6 +71,7 @@ class Category:
         help='Use the taxes defined on the parent category')
     customer_taxes = fields.Many2Many('product.category-customer-account.tax',
         'category', 'tax', 'Customer Taxes',
+        order=[('tax.sequence', 'ASC'), ('tax.id', 'ASC')],
         domain=[('parent', '=', None), ['OR',
                 ('group', '=', None),
                 ('group.kind', 'in', ['sale', 'both'])],
@@ -82,6 +83,7 @@ class Category:
         depends=['taxes_parent'])
     supplier_taxes = fields.Many2Many('product.category-supplier-account.tax',
         'category', 'tax', 'Supplier Taxes',
+        order=[('tax.sequence', 'ASC'), ('tax.id', 'ASC')],
         domain=[('parent', '=', None), ['OR',
                 ('group', '=', None),
                 ('group.kind', 'in', ['purchase', 'both'])],
@@ -125,23 +127,17 @@ class Category:
 
     @fields.depends('account_expense')
     def on_change_account_expense(self):
-        supplier_taxes = []
-        result = {
-            'supplier_taxes': supplier_taxes,
-            }
         if self.account_expense:
-            supplier_taxes.extend(tax.id for tax in self.account_expense.taxes)
-        return result
+            self.supplier_taxes = self.account_expense.taxes
+        else:
+            self.supplier_taxes = []
 
     @fields.depends('account_revenue')
     def on_change_account_revenue(self):
-        customer_taxes = []
-        result = {
-            'customer_taxes': customer_taxes,
-            }
         if self.account_revenue:
-            customer_taxes.extend(tax.id for tax in self.account_revenue.taxes)
-        return result
+            self.customer_taxes = self.account_revenue.taxes
+        else:
+            self.customer_taxes = []
 
 
 class CategoryCustomerTax(ModelSQL):
@@ -222,6 +218,7 @@ class Template:
             help='Use the taxes defined on the category')
     customer_taxes = fields.Many2Many('product.template-customer-account.tax',
         'product', 'tax', 'Customer Taxes',
+        order=[('tax.sequence', 'ASC'), ('tax.id', 'ASC')],
         domain=[('parent', '=', None), ['OR',
                 ('group', '=', None),
                 ('group.kind', 'in', ['sale', 'both'])],
@@ -232,6 +229,7 @@ class Template:
             }, depends=['taxes_category'])
     supplier_taxes = fields.Many2Many('product.template-supplier-account.tax',
         'product', 'tax', 'Supplier Taxes',
+        order=[('tax.sequence', 'ASC'), ('tax.id', 'ASC')],
         domain=[('parent', '=', None), ['OR',
                 ('group', '=', None),
                 ('group.kind', 'in', ['purchase', 'both'])],
@@ -276,29 +274,19 @@ class Template:
 
     @fields.depends('account_category', 'account_expense')
     def on_change_account_expense(self):
-        result = {}
         if not self.account_category:
-            supplier_taxes = []
-            result = {
-                'supplier_taxes': supplier_taxes,
-            }
             if self.account_expense:
-                supplier_taxes.extend(
-                    tax.id for tax in self.account_expense.taxes)
-        return result
+                self.supplier_taxes = self.account_expense.taxes
+            else:
+                self.supplier_taxes = []
 
     @fields.depends('account_category', 'account_revenue')
     def on_change_account_revenue(self):
-        result = {}
         if not self.account_category:
-            customer_taxes = []
-            result = {
-                'customer_taxes': customer_taxes,
-            }
             if self.account_revenue:
-                customer_taxes.extend(
-                    tax.id for tax in self.account_revenue.taxes)
-        return result
+                self.customer_taxes = self.account_revenue.taxes
+            else:
+                self.customer_taxes = []
 
 
 class TemplateCustomerTax(ModelSQL):
